@@ -27,7 +27,7 @@ our @EXPORT = qw(hook debug error htmlpage template template_depends
 	%config %links %pagestate %wikistate %renderedfiles
 	%pagesources %destsources %typedlinks);
 our $VERSION = 3.00; # plugin interface version, next is ikiwiki version
-our $version="3\.20200202\.4";our $installdir="\/usr\/pkg";
+our $version="3\.20250221";our $installdir="\/usr\/pkg";
 # Page dependency types.
 our $DEPEND_CONTENT=1;
 our $DEPEND_PRESENCE=2;
@@ -272,7 +272,7 @@ sub getsetup () {
 	},
 	html5 => {
 		type => "boolean",
-		default => 0,
+		default => 1,
 		description => "use elements new in HTML5 like <section>?",
 		advanced => 0,
 		safe => 1,
@@ -1289,7 +1289,7 @@ sub displaytime ($;$$) {
 	else {
 		return '<span class="date'.
 			($_[2] ? ' dt-published' : '').
-			'"">'.$time.'</span>';
+			'">'.$time.'</span>';
 	}
 }
 
